summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastian Dröge <sebastian.droege@collabora.co.uk>2012-03-27 12:31:18 +0200
committerSebastian Dröge <sebastian.droege@collabora.co.uk>2012-03-27 12:31:18 +0200
commit9c4c9e3b6b1b4750d705ff6a058794468fea4a54 (patch)
treebee9ba30deeb4ea3480fffdc55937d03b016f787
parente08956907c0d48056e9d2b17ee801088771b4481 (diff)
bus: Change the timeout argument type of gst_bus_poll() from GstClockTimeDiff to GstClockTime
This is more consistent with the other GstBus methods that have a timeout.
-rw-r--r--gst/gstbus.c6
-rw-r--r--gst/gstbus.h2
2 files changed, 4 insertions, 4 deletions
diff --git a/gst/gstbus.h b/gst/gstbus.h
index 15bc733ff..2dbf0cef5 100644
--- a/gst/gstbus.h
+++ b/gst/gstbus.h
@@ -162,7 +162,7 @@ guint gst_bus_add_watch (GstBus * bus,
/* polling the bus */
GstMessage* gst_bus_poll (GstBus *bus, GstMessageType events,
- GstClockTimeDiff timeout);
+ GstClockTime timeout);
/* signal based dispatching helper functions. */
gboolean gst_bus_async_signal_func (GstBus *bus, GstMessage *message,
diff --git a/gst/gstbus.c b/gst/gstbus.c
index c4abed2ba..d037566fb 100644
--- a/gst/gstbus.c
+++ b/gst/gstbus.c
@@ -991,7 +991,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
* @bus: a #GstBus
* @events: a mask of #GstMessageType, representing the set of message types to
* poll for.
* @timeout: the poll timeout, as a #GstClockTimeDiff, or -1 to poll
* indefinitely.
*
* Poll the bus for messages. Will block while waiting for messages to come.
@@ -1031,7 +1031,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
* unreffed with gst_message_unref() after usage.
*/
GstMessage *
-gst_bus_poll (GstBus * bus, GstMessageType events, GstClockTimeDiff timeout)
+gst_bus_poll (GstBus * bus, GstMessageType events, GstClockTime timeout)
{
GstBusPollData *poll_data;
GstMessage *ret;
@@ -1043,7 +1043,7 @@ gst_bus_poll (GstBus * bus, GstMessageType events, GstClockTimeDiff timeout)
poll_data->events = events;
poll_data->message = NULL;
- if (timeout >= 0)
+ if (timeout != GST_CLOCK_TIME_NONE)
poll_data->timeout_id = g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
timeout / GST_MSECOND, (GSourceFunc) poll_timeout, poll_data,
(GDestroyNotify) poll_destroy_timeout);
@@ -991,7 +991,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
* @events: a mask of #GstMessageType, representing the set of message types to
* poll for.
- * @timeout: the poll timeout, as a #GstClockTimeDiff, or -1 to poll
+ * @timeout: the poll timeout, as a #GstClockTime, or #GST_CLOCK_TIME_NONE to poll
* indefinitely.
*